@@ -245,12 +245,13 @@ def alerts_query(context, query, sort_by):
 @click.option('--active', default=False, is_flag=True)
 @click.option('--more-info', default=False, is_flag=True)
 @click.option('--team-name', 'team_name', default=False)
+@click.option('--last', prompt=False)
 @click.option('--out-of-office-hours', default=False, is_flag=True)
 @click.option('--not-filtered', default=False, is_flag=True)
 @click.option('--sort-by', "--sort_by", default='status')
 @click.option('--limit', default=100)
 @click.pass_context
-def alerts_list(context, active, limit, more_info, team_name, out_of_office_hours, not_filtered, sort_by):  # pylint: disable=too-many-branches
+def alerts_list(context, active, limit, more_info, team_name, out_of_office_hours, not_filtered, sort_by, last):  # pylint: disable=too-many-branches
     """
     Function to list alerts
 
@@ -260,6 +261,7 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
         more_info: adds the column tags, source, and integration to the output
         team_name: shows the alerts for the team specified
         sort_by: which column to filter by
+        last: retrieving alerts going back for x amount of time
 
     Returns:
         Table output of the list of alerts on success
@@ -274,6 +276,9 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
             "Specify the teamname using --teamname."
         )
 
+    if last and limit == 100:
+        print(f'Note: You might need to increase limit, in order to see all alerts for the period.')
+
     if not_filtered:
         result = context.obj['opsgenie'].query_alerts(f"responders:{team_name} AND tag != filtered AND tag != Filtered", limit)
     else:
@@ -290,11 +295,22 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
         sortedlist = [x for x in sortedlist  \
                         if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour >= 17 \
                         or (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam').hour < 8]
+    if last:
+        if 'm' in last:
+            subtract_period = 'months'
+        if 'w' in last:
+            subtract_period = 'weeks'
+        if 'd' in last:
+            subtract_period = 'days'
+        subtract_value = int(re.sub(r'[mwd]', '', last))
+        args = {subtract_period:subtract_value}
+        subtracted_date = (pendulum.now().in_tz('Europe/Amsterdam')).subtract(**args)
+        sortedlist = [x for x in sortedlist  \
+                        if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam') >= subtracted_date]
     if active:
         sortedlist = [x for x in sortedlist if x['status'] == 'open' and not x['acknowledged']]
 
     format_table = create_and_add_to_pretty_table(table_fields, sortedlist)
-
     output = format_table if len(format_table._rows) > 0 else 'No alerts found..'
     print(output)
 
@@ -1527,7 +1543,7 @@ def schedules_get(context, id_, team_name):
 @schedules.command(name='timeline')
 @click.option('--team-name', 'team_name', required=True)
 @click.option('--expand', type=click.Choice(['base', 'forwarding', 'override'], case_sensitive=False))
-@click.option('--interval', default=1)
+@click.option('--interval', default=2)
 @click.option('--intervalunit', default='months')
 @click.option('--history', is_flag=True)
 @click.pass_context
@@ -1569,9 +1585,9 @@ def schedules_timeline(context, team_name, history, expand, interval, intervalun
 @click.option('--end-date', 'end_date', help='Example: 2020-06-27', required=True)
 @click.option('--exclude-engineer', 'exclude_engineer')
 @click.pass_context
-def schedules_timeline(context, team_name, start_date, end_date, exclude_engineer):  # pylint: disable=too-many-locals, too-many-arguments
+def reshuffle_timeline(context, team_name, start_date, end_date, exclude_engineer):  # pylint: disable=too-many-locals, too-many-arguments
     """
-    Function to list the schedules for all teams
+    Function to reshuffle the schedules for all teams
 
     Returns:
         Table output listing the schedules for all teams in the format of two columns: id and name
